/*
 *	Sherlock Gatherer: List of known parsers
 */

P(sink)
P(text)
P(html)
P(gzip)
P(deflate)
P(compress)
P(robots)
P(external)
#ifdef CONFIG_IMAGES
  P(image)
#endif
#ifdef CONFIG_PDF
  P(pdf)
#endif
